# Changelog

All notable changes to this project are documented in this file.

## [3.2.4] - 2026-03-20

### Changed

- Fixed preview server HTML requests to render the requested page without rebuilding the whole site.
- Updated README and docs pages to match the current positional CLI usage.
- Switched the docs theme to `mkdocs-shadcn` and aligned Markdown highlighting with the theme.
- Bumped package version to `3.2.4`.

## [3.2.3] - 2026-03-07

### Changed

- Removed `ipython` from runtime dependencies.
- Bumped package version to `3.2.3`.

## [3.2.2] - 2026-03-05

### Changed

- Bumped package version to `3.2.2`.
